
import { env } from "@/env.mjs"
import { db } from "@/lib/db"
import getURL from "@/lib/utils"
import { randomUUID } from "crypto"
import { NextResponse } from "next/server"
import nodemailer from "nodemailer"

export async function POST(req: Request) {
    const { email } = await req.json()
    const transporter = nodemailer.createTransport({
        service: 'gmail',
        host: 'smtp.gmail.com',
        auth: {
            user: env.NODEMAIL_MAIL,
            pass: env.NODEMAIL_PW,
        },
    })

    const user = await db.user.findFirst({
        where: {
            email: email
        }
    })

    const token = await db.activationToken.create({
        data: {
            token: `${randomUUID()}${randomUUID()}`.replace(/-/g, ''),
            userId: user?.id!
        },
    })

    const mailData = {
        from: env.NODEMAIL_MAIL,
        to: email,
        subject: `Email Verification for your GameUnity Account`,
        html: `Hello ${user?.name} Please follow the Link: ${getURL(`/api/verification/${token.token}`)} and verify your email address.`,
    }

    let emailRes
    try {
        emailRes = await transporter.sendMail(mailData)
        console.log("Message sent", emailRes.messageId)
    } catch (err) {
        console.log(err)
        console.error("Error email could not be send")
    }

    return NextResponse.json({ success: true, messageId: emailRes?.messageId })
}